@@ -44,6 +44,7 @@ from urllib3.exceptions import InsecureRequestWarning
 from ._version import _TITLE, _VERSION
 from ._result import Result
 from ._base_url import BaseURL
+from ._uber_default_preference import PREFER_NONETYPE
 urllib3.disable_warnings(InsecureRequestWarning)
 
 # Restrict requests to only allowed HTTP methods
@@ -271,9 +272,14 @@ def perform_request(endpoint: str = "", headers: dict = None, **kwargs) -> objec
     return returned
 
 
-def generate_error_result(message: str = "An error has occurred. Check your payloads and try again.", code: int = 500) -> dict:
+def generate_error_result(
+        message: str = "An error has occurred. Check your payloads and try again.",
+        code: int = 500,
+        **kwargs
+        ) -> dict:
     """Normalize error messages."""
-    return Result()(status_code=code, headers={}, body={"errors": [{"message": f"{message}"}], "resources": []})
+    return_headers = kwargs.get("headers", {})
+    return Result()(status_code=code, headers=return_headers, body={"errors": [{"message": f"{message}"}], "resources": []})
 
 
 def generate_ok_result(message: str = "Request returned with success", code: int = 200, **kwargs) -> dict:
@@ -419,12 +425,18 @@ def confirm_base_url(provided_base: str = "https://api.crowdstrike.com") -> str:
     returned_base = provided_base
     if "://" not in provided_base:
         # They're passing the name instead of the URL
+        dashed_bases = ["US-1", "US-2", "EU-1", "US-GOV-1"]
+        if provided_base.upper() in dashed_bases:
+            provided_base = provided_base.replace("-", "")  # Strip the dash
         try:
             returned_base = f"https://{BaseURL[provided_base.upper()].value}"
         except KeyError:
             # Invalid base URL name, fall back to assuming they didn't give us https
             returned_base = f"https://{provided_base}"
 
+    if returned_base[-1] == "/":  # Issue 558
+        returned_base = returned_base[:-1]
+
     return returned_base
 
 
@@ -433,6 +445,18 @@ def confirm_base_region(provided_base_url: str = "https://api.crowdstrike.com")
     try:
         shortname = BaseURL(provided_base_url.replace("https://", "").lower()).name
     except (KeyError, ValueError):
-        shortname = "us1"  # Fall back to US-1
+        shortname = "US1"  # Fall back to US-1
 
     return shortname
+
+
+def return_preferred_default(method_name: str = None, keyword_type: str = "dict"):
+    """Use the PREFER_NONETYPE list lookup to determine the default to use for empty payloads."""
+    default_return = {}
+    if method_name:
+        if keyword_type.lower() == "list":
+            default_return = []
+        if method_name in PREFER_NONETYPE:
+            default_return = None
+
+    return default_return
