@@ -38,7 +38,8 @@ For more information, please refer to <https://unlicense.org>
 import time
 from ._util import _ALLOWED_METHODS
 from ._util import perform_request, generate_b64cred, generate_error_result
-from ._util import confirm_base_url, args_to_params, confirm_base_region
+from ._util import confirm_base_url, args_to_params, confirm_base_region, return_preferred_default
+from ._token_fail_reason import TokenFailReason
 from ._endpoint import api_endpoints
 
 
@@ -46,8 +47,7 @@ class APIHarness:
     """This one does it all. It's like the One Ring with significantly fewer orcs."""
 
     # pylint: disable=too-many-instance-attributes
-
-    TOKEN_RENEW_WINDOW = 20  # in seconds
+    _token_fail_headers = {}  # Issue #578
 
     def __init__(self: object,  # pylint: disable=R0913
                  base_url: str = "https://api.crowdstrike.com",
@@ -58,7 +58,8 @@ class APIHarness:
                  ssl_verify: bool = True,
                  proxy: dict = None,
                  timeout: float or tuple = None,
-                 user_agent: str = None
+                 user_agent: str = None,
+                 renew_window: int = 120
                  ) -> object:
         """Uber class constructor.
 
@@ -67,22 +68,25 @@ class APIHarness:
         Afterwards class attributes are initialized.
 
         Keyword arguments:
-        base_url -- CrowdStrike API URL to use for requests. [Default: US-1]
-        ssl_verify -- Boolean specifying if SSL verification should be used. [Default: True]
-        proxy -- Dictionary of proxies to be used for requests.
-        timeout -- Float or tuple specifying timeouts to use for requests.
-        creds -- Dictionary containing CrowdStrike API credentials.
-                 Mutually exclusive to client_id / client_secret.
-                 {
-                     "client_id": "CLIENT_ID_HERE",
-                     "client_secret": "CLIENT_SECRET_HERE",
-                     "member_cid": "CHILD_CID_MSSP_ONLY"
-                 }
-        client_id -- Client ID for the CrowdStrike API. Mutually exclusive to creds.
-        client_secret -- Client Secret for the CrowdStrike API. Mutually exclusive to creds.
-        member_cid -- Child CID to connect to. (MSSP only) Mutually exclusive to creds.
-        user_agent -- User-Agent string to use for all requests made to the CrowdStrike API.
-                      String. Defaults to crowdstrike-falconpy/VERSION.
+        base_url: CrowdStrike API URL to use for requests. [Default: US-1]
+        ssl_verify: Boolean specifying if SSL verification should be used. [Default: True]
+        proxy: Dictionary of proxies to be used for requests.
+        timeout: Float or tuple specifying timeouts to use for requests.
+        creds: Dictionary containing CrowdStrike API credentials.
+               Mutually exclusive to client_id / client_secret.
+               {
+                   "client_id": "CLIENT_ID_HERE",
+                   "client_secret": "CLIENT_SECRET_HERE",
+                   "member_cid": "CHILD_CID_MSSP_ONLY"
+               }
+        client_id: Client ID for the CrowdStrike API. Mutually exclusive to creds.
+        client_secret: Client Secret for the CrowdStrike API. Mutually exclusive to creds.
+        member_cid: Child CID to connect to. (MSSP only) Mutually exclusive to creds.
+        user_agent: User-Agent string to use for all requests made to the CrowdStrike API.
+                    String. Defaults to crowdstrike-falconpy/VERSION.
+        renew_window: Amount of time (in seconds) between now and the token expiration before
+                      a refresh of the token is performed. Default: 120, Max: 1200
+                      Values over 1200 will be reset to the maximum.
 
         This method only accepts keywords to specify arguments.
         """
@@ -111,6 +115,8 @@ class APIHarness:
         self.headers = lambda: {"Authorization": f"Bearer {self.token}"} if self.token else {}
         self.commands = api_endpoints
         self.user_agent = user_agent  # Issue #365
+        # Maximum renewal window is 20 minutes, Minimum is 2 minutes
+        self.token_renew_window = max(min(renew_window, 1200), 120)  # in seconds
 
     def valid_cred_format(self: object) -> bool:
         """Confirm credential dictionary format.
@@ -127,7 +133,7 @@ class APIHarness:
     def token_expired(self: object) -> bool:
         """Return a boolean based upon the token expiration status."""
         retval = False
-        if (time.time() - self.token_time) >= (self.token_expiration - self.TOKEN_RENEW_WINDOW):
+        if (time.time() - self.token_time) >= (self.token_expiration - self.token_renew_window):
             retval = True
 
         return retval
@@ -172,12 +178,13 @@ class APIHarness:
                     self.base_url = confirm_base_url(token_region.upper())
             else:
                 self.authenticated = False
+                self._token_fail_headers = result["headers"]
                 if "errors" in result["body"]:
                     if result["body"]["errors"]:
                         self.token_fail_reason = result["body"]["errors"][0]["message"]
         else:
             self.authenticated = False
-            self.token_fail_reason = "Unexpected API response received"
+            self.token_fail_reason = TokenFailReason["UNEXPECTED"].value
             self.token_status = 403
 
         return self.authenticated
@@ -265,19 +272,22 @@ class APIHarness:
             if self.authenticated:
                 # Which HTTP method to execute
                 selected_method = uber_command[0][1].upper()
+                selected_operation = uber_command[0][0]
                 # Only accept allowed HTTP methods
                 if selected_method in _ALLOWED_METHODS:
                     returned = perform_request(method=selected_method,
                                                endpoint=target,
-                                               body=kwargs.get("body", {}),
-                                               data=kwargs.get("data", {}),
+                                               body=kwargs.get("body", return_preferred_default(selected_operation)),
+                                               data=kwargs.get("data", return_preferred_default(selected_operation)),
                                                params=args_to_params(kwargs.get("parameters", {}),
                                                                      kwargs,
                                                                      self.commands,
-                                                                     uber_command[0][0]
+                                                                     selected_operation
                                                                      ),
                                                headers=self._create_header_payload(kwargs),
-                                               files=kwargs.get("files", []),
+                                               files=kwargs.get("files",
+                                                                return_preferred_default(selected_operation, "list")
+                                                                ),
                                                verify=self.ssl_verify,
                                                proxy=self.proxy,
                                                timeout=self.timeout,
@@ -290,7 +300,10 @@ class APIHarness:
                                                      )
             else:
                 # Invalid token / Bad creds
-                returned = generate_error_result(message="Failed to issue token.", code=401)
+                returned = generate_error_result(message="Failed to issue token.",
+                                                 code=401,
+                                                 headers=self._token_fail_headers
+                                                 )
         else:
             # That command doesn't exist, have a cup of tea instead
             returned = generate_error_result(message="Invalid API operation specified.", code=418)
