@@ -130,6 +130,9 @@ class RealTimeResponseAdmin(ServiceClass):
         https://assets.falcon.crowdstrike.com/support/api/swagger.html#
                     /real-time-response-admin/RTR_CheckAdminCommandStatus
         """
+        if not kwargs.get("sequence_id", None) and not parameters.get("sequence_id", None):
+            parameters["sequence_id"] = 0
+
         return process_service_request(
             calling_object=self,
             endpoints=Endpoints,
